@@ -263,8 +263,24 @@ class DataProcessor(object):
         if cols:
             data.drop(cols, axis=1, inplace=True, **kwargs)
 
-    @staticmethod
-    def date_cols(data, cols=None):
+    def date_cols(self, data, cols=None):
+        """Process the date columns. This method, decides whether we should use multiprocessing or not. It then calls
+        the appropriate methods. The method _handle_date_cols does the actual work.
+
+        :param data: pandas dataframe
+        :param cols: the date columns to be processed
+        :return: the updated dataframe with the new columns
+        """
+        if cols:
+            if self.conf.process.date_cols_num_cores == 1 or self.conf.process.date_cols_num_cores is None:
+                data = self._handle_date_cols(data, cols)
+            else:
+                data = parrallelize_dataframe(data, partial(self._handle_date_cols, cols=cols),
+                                              num_cores=self.conf.process.date_cols_num_cores)
+
+            return data
+
+    def _handle_date_cols(self, data, cols=None):
         """Process the date columns. First, convert each column to datetime object and then extract the requested items
         from them to create the new columns.
 
@@ -272,15 +288,14 @@ class DataProcessor(object):
         :param cols: the date columns to be processed
         :return: the updated dataframe with the new columns
         """
-        if cols:
-            for col, date_items in cols.items():
-                data[col] = pd.to_datetime(data[col],
-                                           errors='coerce',
-                                           infer_datetime_format=True)
-                for item in date_items:
-                    data.loc[:, f"{col}_{item}"] = getattr(data[col].dt, item)
+        for col, date_items in cols.items():
+            data[col] = pd.to_datetime(data[col],
+                                       errors='coerce',
+                                       infer_datetime_format=True)
+            for item in date_items:
+                data.loc[:, f"{col}_{item}"] = getattr(data[col].dt, item)
 
-            return data
+        return data
 
     def handle_mean(self, data):
         """Accept a dataframe and compute the mean of all columns in that dataframe and save them in a dictionary (mean_dict)
